==> yy-formulas-1.0.1.tgz: package/es/components/SubjectComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import TreeSelect, { TreeNode } from 'rc-tree-select';

var SubjectComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(SubjectComponents, _React$Component);

  function SubjectComponents(props) {
    var _this;

    _classCallCheck(this, SubjectComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SubjectComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onTreeSelectChange = _this.onTreeSelectChange.bind(_assertThisInitialized(_this));
    _this.state = {
      activeItem: null,
      activeKey: '',
      treeList: [],
      value: ''
    };
    return _this;
  }

  _createClass(SubjectComponents, [{
    key: "onChange",
    value: function onChange(event) {
      this.setState({
        value: event.target.value
      });
    }
  }, {
    key: "onClick",
    value: function onClick(item) {
      var activeKey = item.id;
      var treeList = [];
      var activeItem = null;

      if (item.id === this.state.activeKey) {
        activeKey = '';
      } else {
        activeItem = item;
        Object.keys(item).forEach(function (key) {
          var regexp = new RegExp('^classtype', 'igm');

          if (regexp.test(key) && item[key]) {
            treeList.push(item[key]);
          }
        });
      } // console.log(treeList)


      this.setState({
        treeList: treeList,
        activeKey: activeKey,
        activeItem: activeItem
      });
    }
  }, {
    key: "onTreeSelectChange",
    value: function onTreeSelectChange(item, index, value, label, extra) {
      var _this2 = this;

      var treeList = JSON.parse(JSON.stringify(this.state.treeList));
      treeList[index] = _extends(item, {
        value: value
      });
      this.setState({
        treeList: treeList
      }, function () {
        if (value) {
          var str = ' cmapping("' + _this2.state.activeItem.code + '/' + _this2.state.activeItem.name + '","' + _this2.state.activeItem.id + '","' + extra.triggerNode.props.code + '") ';

          _this2.props.onInsertValue(str);

          _this2.props.onDesc('cmapping');
        }
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var DocumentTreeData = this.props.DocumentTreeData; // let value = this.state.value

      console.log(DocumentTreeData);

      var loop = function loop(data) {
        // console.log(data)
        return data.map(function (item) {
          // let isflag = false
          // if(value && value.length > 0){
          //   let reg = new RegExp(value,'igm')
          //   isflag = reg.test(item.title)
          //   // console.log(isflag)
          // }else{
          //   // console.log(isflag)
          // }
          if (item.children && item.children.length > 0) {
            return React.createElement(TreeNode, {
              title: item.title,
              isLeaf: false,
              key: item.key,
              code: item.code,
              disabled: item.disabled,
              value: item.title // className={isflag ? 'yy-search-selected' : ''}

            }, loop(item.children));
          } else {
            return React.createElement(TreeNode, {
              title: item.title,
              isLeaf: true,
              key: item.key,
              code: item.code,
              disabled: item.disabled,
              value: item.title // className={isflag ? 'yy-search-selected' : ''}

            });
          }
        });
      };

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, "\u5B9A\u4F4D\uFF1A"), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      }))), React.createElement("div", null, React.createElement("ul", {
        className: "nav nav-pills nav-stacked"
      }, this.props.SubjectData.map(function (item) {
        var flag = false;

        if (_this3.state.value && _this3.state.value.length > 0) {
          var regexp = new RegExp(_this3.state.value, 'igm');

          if (regexp.test(item.code + '' + item.name)) {
            flag = true;
          }
        }

        var className = _this3.state.activeKey == item.id ? 'active' : '';
        className = className + (flag ? ' subject-search' : '');
        return React.createElement("li", {
          onClick: _this3.onClick.bind(_this3, item),
          className: className,
          key: item.id
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.code, " / ", item.name));
      }))), React.createElement("hr", null), React.createElement("form", {
        className: "form-horizontal"
      }, this.state.treeList.map(function (item, index) {
        return React.createElement("div", {
          key: item.id,
          className: "form-group"
        }, React.createElement("label", {
          className: "col-sm-2 control-label"
        }, item.name), React.createElement("div", {
          className: "col-sm-10"
        }, React.createElement(TreeSelect, {
          showSearch: true,
          showLine: true,
          style: {
            width: '100%'
          },
          value: item.value,
          dropdownStyle: {
            maxHeight: 300,
            overflow: 'auto'
          },
          placeholder: "\u8BF7\u8F93\u5165...",
          notFoundContent: "\u6682\u65E0\u6570\u636E",
          allowClear: true,
          treeDefaultExpandAll: true,
          onChange: _this3.onTreeSelectChange.bind(_this3, item, index)
        }, loop(DocumentTreeData))));
      })));
    }
  }]);

  return SubjectComponents;
}(React.Component);

SubjectComponents.propTypes = {
  item: PropTypes.object
};
SubjectComponents.defaultProps = {
  item: {}
};
polyfill(SubjectComponents);
export default SubjectComponents;

==> yy-formulas-1.0.7.tgz: package/es/components/SubjectComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import TreeSelect, { TreeNode } from 'rc-tree-select';

var SubjectComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(SubjectComponents, _React$Component);

  function SubjectComponents(props) {
    var _this;

    _classCallCheck(this, SubjectComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SubjectComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onTreeSelectChange = _this.onTreeSelectChange.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.state = {
      activeItem: null,
      activeKey: '',
      treeList: [],
      value: ''
    };
    return _this;
  }

  _createClass(SubjectComponents, [{
    key: "onChange",
    value: function onChange(event) {
      this.setState({
        value: event.target.value
      });
    }
  }, {
    key: "onClick",
    value: function onClick(item) {
      var activeKey = item.id;
      var treeList = [];
      var activeItem = null;

      if (item.id === this.state.activeKey) {
        activeKey = '';
      } else {
        activeItem = item;
        Object.keys(item).forEach(function (key) {
          var regexp = new RegExp('^classtype', 'igm');

          if (regexp.test(key) && item[key]) {
            treeList.push(item[key]);
          }
        });
      } // console.log(treeList)


      this.setState({
        treeList: treeList,
        activeKey: activeKey,
        activeItem: activeItem
      });
    }
  }, {
    key: "onTreeSelectChange",
    value: function onTreeSelectChange(item, index, value, label, extra) {
      var _this2 = this;

      var treeList = JSON.parse(JSON.stringify(this.state.treeList));
      treeList[index] = _extends(item, {
        value: value
      });
      this.setState({
        treeList: treeList
      }, function () {
        if (value) {
          var str = ' cmapping("' + _this2.state.activeItem.code + '/' + _this2.state.activeItem.name + '","' + _this2.state.activeItem.id + '","' + extra.triggerNode.props.code + '") ';

          _this2.props.onInsertValue(str);

          _this2.props.onDesc('cmapping');
        }
      });
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var _this3 = this;

      if (!this.state.value) return false;
      var activeKey = this.state.activeKey;
      if (!this.state.value) return false;
      var searchIndex = [];
      this.props.SubjectData.forEach(function (item) {
        var regexp = new RegExp(_this3.state.value, 'igm');

        if (regexp.test(item.code + '' + item.name)) {
          searchIndex.push(item.id);
        }
      });
      if (searchIndex.length === 0) return false;
      var index2 = searchIndex.indexOf(this.state.activeKey);

      if (index2 == -1) {
        activeKey = searchIndex[0];
      } else {
        if (searchIndex[index2 + 1]) {
          activeKey = searchIndex[index2 + 1];
        } else {
          activeKey = searchIndex[0];
        }
      }

      var treeList = [];
      var activeItem = null;
      this.props.SubjectData.forEach(function (item) {
        if (item.id == activeKey) {
          activeItem = item;
          Object.keys(item).forEach(function (key) {
            var regexp = new RegExp('^classtype', 'igm');

            if (regexp.test(key) && item[key]) {
              treeList.push(item[key]);
            }
          });
        }
      });
      this.setState({
        activeKey: activeKey,
        treeList: treeList,
        activeItem: activeItem
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var DocumentTreeData = this.props.DocumentTreeData; // let value = this.state.value
      // console.log(DocumentTreeData)

      var loop = function loop(data) {
        // console.log(data)
        return data.map(function (item) {
          // let isflag = false
          // if(value && value.length > 0){
          //   let reg = new RegExp(value,'igm')
          //   isflag = reg.test(item.title)
          //   // console.log(isflag)
          // }else{
          //   // console.log(isflag)
          // }
          if (item.children && item.children.length > 0) {
            return React.createElement(TreeNode, {
              title: item.title,
              isLeaf: false,
              key: item.key,
              code: item.code,
              disabled: item.disabled,
              value: item.title // className={isflag ? 'yy-search-selected' : ''}

            }, loop(item.children));
          } else {
            return React.createElement(TreeNode, {
              title: item.title,
              isLeaf: true,
              key: item.key,
              code: item.code,
              disabled: item.disabled,
              value: item.title // className={isflag ? 'yy-search-selected' : ''}

            });
          }
        });
      };

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement("div", null, React.createElement("ul", {
        className: "nav nav-pills nav-stacked"
      }, this.props.SubjectData.map(function (item) {
        // let flag = false
        // if(this.state.value && this.state.value.length > 0){
        //   let regexp = new RegExp(this.state.value,'igm')
        //   if(regexp.test(item.code+''+item.name)){
        //     flag=true
        //   }
        // }
        // let className = this.state.activeKey == item.id ? 'active' : ''
        // className = className + (flag ? ' subject-search' : '')
        return React.createElement("li", {
          onClick: _this4.onClick.bind(_this4, item),
          className: _this4.state.activeKey == item.id ? 'active' : '',
          key: item.id
        }, React.createElement("a", {
          href: "javascript:void(0)"
        }, item.code, " / ", item.name));
      }))), React.createElement("hr", null), React.createElement("form", {
        className: "form-horizontal"
      }, this.state.treeList.map(function (item, index) {
        return React.createElement("div", {
          key: item.id,
          className: "form-group"
        }, React.createElement("label", {
          className: "col-sm-2 control-label"
        }, item.name), React.createElement("div", {
          className: "col-sm-10"
        }, React.createElement(TreeSelect, {
          showSearch: true,
          showLine: true,
          style: {
            width: '100%'
          },
          value: item.value,
          dropdownStyle: {
            maxHeight: 300,
            overflow: 'auto'
          },
          placeholder: _this4.props.item.placeholder // "请输入..."
          ,
          notFoundContent: _this4.props.item.notFoundContent // "暂无数据"
          ,
          allowClear: true,
          treeDefaultExpandAll: true,
          onChange: _this4.onTreeSelectChange.bind(_this4, item, index)
        }, loop(JSON.parse(JSON.stringify(DocumentTreeData))))));
      })));
    }
  }]);

  return SubjectComponents;
}(React.Component);

SubjectComponents.propTypes = {
  item: PropTypes.object
};
SubjectComponents.defaultProps = {
  item: {}
};
polyfill(SubjectComponents);
export default SubjectComponents;
